@@ -31,7 +31,7 @@ type LiveView struct {
 	title                     string
 	model                     model.ResourceViewer
 	text                      *tview.TextView
-	actions                   ui.KeyActions
+	actions                   *ui.KeyActions
 	app                       *App
 	cmdBuff                   *model.FishBuff
 	currentRegion, maxRegions int
@@ -48,7 +48,7 @@ func NewLiveView(app *App, title string, m model.ResourceViewer) *LiveView {
 		text:          tview.NewTextView(),
 		app:           app,
 		title:         title,
-		actions:       make(ui.KeyActions),
+		actions:       ui.NewKeyActions(),
 		currentRegion: 0,
 		maxRegions:    0,
 		cmdBuff:       model.NewFishBuff('/', model.FilterBuffer),
@@ -139,7 +139,7 @@ func (v *LiveView) BufferActive(state bool, k model.BufferKind) {
 }
 
 func (v *LiveView) bindKeys() {
-	v.actions.Set(ui.KeyActions{
+	v.actions.Bulk(ui.KeyMap{
 		tcell.KeyEnter:  ui.NewSharedKeyAction("Filter", v.filterCmd, false),
 		tcell.KeyEscape: ui.NewKeyAction("Back", v.resetCmd, false),
 		tcell.KeyCtrlS:  ui.NewKeyAction("Save", v.saveCmd, false),
@@ -153,19 +153,13 @@ func (v *LiveView) bindKeys() {
 	})
 
 	if !v.app.Config.K9s.IsReadOnly() {
-		v.actions.Add(ui.KeyActions{
-			ui.KeyE: ui.NewKeyAction("Edit", v.editCmd, true),
-		})
+		v.actions.Add(ui.KeyE, ui.NewKeyAction("Edit", v.editCmd, true))
 	}
 	if v.title == yamlAction {
-		v.actions.Add(ui.KeyActions{
-			ui.KeyM: ui.NewKeyAction("Toggle ManagedFields", v.toggleManagedCmd, true),
-		})
+		v.actions.Add(ui.KeyM, ui.NewKeyAction("Toggle ManagedFields", v.toggleManagedCmd, true))
 	}
 	if v.model != nil && v.model.GVR().IsDecodable() {
-		v.actions.Add(ui.KeyActions{
-			ui.KeyX: ui.NewKeyAction("Toggle Decode", v.toggleEncodedDecodedCmd, true),
-		})
+		v.actions.Add(ui.KeyX, ui.NewKeyAction("Toggle Decode", v.toggleEncodedDecodedCmd, true))
 	}
 }
 
@@ -210,7 +204,7 @@ func (v *LiveView) toggleRefreshCmd(evt *tcell.EventKey) *tcell.EventKey {
 }
 
 func (v *LiveView) keyboard(evt *tcell.EventKey) *tcell.EventKey {
-	if a, ok := v.actions[ui.AsKey(evt)]; ok {
+	if a, ok := v.actions.Get(ui.AsKey(evt)); ok {
 		return a.Action(evt)
 	}
 
@@ -225,7 +219,7 @@ func (v *LiveView) StylesChanged(s *config.Styles) {
 }
 
 // Actions returns menu actions.
-func (v *LiveView) Actions() ui.KeyActions {
+func (v *LiveView) Actions() *ui.KeyActions {
 	return v.actions
 }
 
